##  Fact Sheet Order and Colors in the Meta Model v4
The following table lists the default order and colors of fact sheets in the meta model v4.
**Fact Sheet Order and Colors in the Meta Model v4** Order | Fact Sheet Type | HEX Color Value
---|---|---
1 | Objective | #C7527D
2 | Platform | #027446
3 | Initiative | #33CC58
4 | Business Capability | #003399
5 | Business Context | #FE6690
6 | Organization | #2889FF
7 | Application | #0F7EB5
8 | Interface | #02AFA4
9 | Data Object | #774FCC
10 | IT Component | #D29270
11 | Provider | #FFA31F
12 | Tech Category | #A6566D


**Tip**
Recommendation: Although you have the flexibility to change the order and colors of fact sheets, adhering to the standard settings allows your organization to use various enablement resources provided by SAP LeanIX, including documentation, more efficiently.
